/**
 * Required External Modules and Interfaces
 */
import express, {Request, Response} from 'express';
import logger from '../../middleware/logger';
import {Guid} from 'guid-typescript';
import * as ChangeService from './changes/changes.service';

/**
 * Router Definition
 */
export const dhbwRaPlaChangesRouter = express.Router();

dhbwRaPlaChangesRouter.get('/', async (req: Request, res: Response) => {
	try {
		let week = (req.query.week ?? '').toString();

		let changes = await ChangeService.getChanges('TINF19B4', week);

		res.status(200).send(changes);
	} catch (e: any) {
		let errorGuid = Guid.create().toString();
		logger.error('Error handling a request: ' + e.message, {reference: errorGuid});
		res.status(500).send({
			'status': 'PROCESSING_ERROR',
			'message': 'Internal Server Error. Try again later.',
			'reference': errorGuid
		});
	}
});

dhbwRaPlaChangesRouter.get('/:id', async (req: Request, res: Response) => {
	try {
		let id: string = (req.params.id ?? '').toString();

		let changes = await ChangeService.getEventById('TINF19B4', id);

		res.status(200).send(changes);
	} catch (e: any) {
		let errorGuid = Guid.create().toString();
		logger.error('Error handling a request: ' + e.message, {reference: errorGuid});
		res.status(500).send({
			'status': 'PROCESSING_ERROR',
			'message': 'Internal Server Error. Try again later.',
			'reference': errorGuid
		});
	}
});
